<?xml version="1.0" ?><!DOCTYPE TS><TS language="sv" version="2.0">
<context>
    <name>AddProfileWindow</name>
    <message>
        <location filename="../../views/profile_add_edit_dialog.py" line="27"/>
        <source>Please enter a profile name.</source>
        <translation>Ange ett profilnamn.</translation>
    </message>
    <message>
        <location filename="../../views/profile_add_edit_dialog.py" line="28"/>
        <source>A profile with this name already exists.</source>
        <translation>Det finns redan en profil med det här namne.</translation>
    </message>
    <message>
        <location filename="../../views/profile_add_edit_dialog.py" line="24"/>
        <source>Save</source>
        <translation>Spara</translation>
    </message>
    <message>
        <location filename="../../views/profile_add_edit_dialog.py" line="25"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
</context>
<context>
    <name>AddRepoWindow</name>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="80"/>
        <source>Repository Path:</source>
        <translation>Förrådssökväg:</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="83"/>
        <source>Choose Location of Borg Repository</source>
        <translation>Välj en plats för Borg-förrådet</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="112"/>
        <source>Repository URL:</source>
        <translation>Förrådets URL:</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="138"/>
        <source>Unable to add your repository.</source>
        <translation>Kunde inte lägga till ditt förråd.</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="165"/>
        <source>Please enter a valid repo URL or select a local path.</source>
        <translation>Ange en giltig förråds-URL eller välj en lokal mapp.</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="169"/>
        <source>This repo has already been added.</source>
        <translation>Detta förråd har redan lagts till.</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="105"/>
        <source>Show my passwords</source>
        <translation>Visa mina lösenord</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="90"/>
        <source>Autofilled password from password manager.</source>
        <translation>Automatiskt ifyllt lösenord från lösenordshanterare.</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="102"/>
        <source>Hide my passwords</source>
        <translation>Dölj mina lösenord</translation>
    </message>
</context>
<context>
    <name>AddRepository</name>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="60"/>
        <source>Initialize New Backup Repository</source>
        <translation>Starta nytt säkerhetskopieringsförråd</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="67"/>
        <source>Repository URL:</source>
        <translation>Förråds-URL:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="82"/>
        <source>csvis8xq@csvis8xq.repo.borgbase.com:repo</source>
        <translation>csvis8xq@csvis8xq.repo.borgbase.com:repo</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="89"/>
        <source>Choose a local path as repository.</source>
        <translation>Välj en lokal mapp som förråd.</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="103"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="201"/>
        <source>Encryption:</source>
        <translation>Kryptering:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="179"/>
        <source>SSH Key:</source>
        <translation>SSH-nyckel:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="193"/>
        <source>Automatically choose SSH Key (default)</source>
        <translation>Välj SSH-nyckel automatiskt (standard)</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="247"/>
        <source>Add</source>
        <translation>Lägg till</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="254"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="33"/>
        <source>General</source>
        <translation>Allmänt</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="158"/>
        <source>Advanced</source>
        <translation>Avancerat</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="218"/>
        <source>Extra Borg Arguments:</source>
        <translation>Extra Borg-argument:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="116"/>
        <source>Borg passphrase:</source>
        <translation>Borg-lösenfras:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="143"/>
        <source>Confirm passphrase:</source>
        <translation>Bekräfta lösenfras:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repoadd.ui" line="150"/>
        <source>TextLabel</source>
        <translation>TextEtikett</translation>
    </message>
</context>
<context>
    <name>ArchiveTab</name>
    <message>
        <location filename="../../views/archive_tab.py" line="144"/>
        <source>Archives for %s</source>
        <translation>Arkiv för %s</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="177"/>
        <source>Archives</source>
        <translation>Arkiv</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="194"/>
        <source>Preview: %s</source>
        <translation>Förhandsgranska: %s</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="198"/>
        <source>Error in archive name template.</source>
        <translation>Fel i arkivets namnmall.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="242"/>
        <source>Pruning finished.</source>
        <translation>Beskärning slutförd.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="261"/>
        <source>Refreshed archives.</source>
        <translation>Uppdaterade arkiv.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="315"/>
        <source>Choose Mount Point</source>
        <translation>Välj monteringspunkt</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="321"/>
        <source>Mounted successfully.</source>
        <translation>Montering slutförd.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="348"/>
        <source>Mount point not active.</source>
        <translation>Monteringspunkt inte aktiv.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="355"/>
        <source>Un-mounted successfully.</source>
        <translation>Avmontering slutförd.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="393"/>
        <source>Select an archive to restore first.</source>
        <translation>Välj först ett arkiv att återställa.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="413"/>
        <source>Choose Extraction Point</source>
        <translation>Välj extraheringspunkt</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="478"/>
        <source>Archive deleted.</source>
        <translation>Arkiv borttaget.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="463"/>
        <source>Confirm deletion</source>
        <translation>Bekräfta borttagning</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="563"/>
        <source>No archive selected</source>
        <translation>Inget arkiv valt</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="463"/>
        <source>Are you sure you want to delete the archive?</source>
        <translation>Vill du verkligen ta bort arkivet?</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="449"/>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="450"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="98"/>
        <source>Action cancelled.</source>
        <translation>Åtgärden avbruten.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="361"/>
        <source>Unmounting failed. Make sure no programs are using {}</source>
        <translation>Avmontering misslyckades. Tillse att inget program använder {}</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="117"/>
        <source>Select an archive first.</source>
        <translation>Välj ett arkiv först.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="537"/>
        <source>Change name</source>
        <translation>Byt namn</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="537"/>
        <source>New archive name:</source>
        <translation>Nytt arkivnamn:</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="547"/>
        <source>Archive name cannot be blank.</source>
        <translation>Arkivnamnet kan inte lämnas tomt.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="552"/>
        <source>An archive with this name already exists.</source>
        <translation>Det finns redan ett arkiv med det namnet.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="567"/>
        <source>Archive renamed.</source>
        <translation>Arkiv namnändrat.</translation>
    </message>
    <message>
        <location filename="../../views/archive_tab.py" line="278"/>
        <source>Refreshed archive.</source>
        <translation>Uppdaterade arkiv.</translation>
    </message>
</context>
<context>
    <name>BorgBreakJob</name>
    <message>
        <location filename="../../borg/break_lock.py" line="8"/>
        <source>Breaking repository lock...</source>
        <translation>Bryter förrådslås...</translation>
    </message>
    <message>
        <location filename="../../borg/break_lock.py" line="12"/>
        <source>Repository lock broken. Please redo your last action.</source>
        <translation>Förrådslås uppbrutet. Upprepa senaste åtgärden.</translation>
    </message>
</context>
<context>
    <name>BorgCheckJob</name>
    <message>
        <location filename="../../borg/check.py" line="8"/>
        <source>Starting consistency check...</source>
        <translation>Startar konsekvenskontroll...</translation>
    </message>
    <message>
        <location filename="../../borg/check.py" line="17"/>
        <source>Check completed.</source>
        <translation>Kontroll slutförd.</translation>
    </message>
    <message>
        <location filename="../../borg/check.py" line="14"/>
        <source>Repo check failed. See logs for details.</source>
        <translation>Förrådskontroll misslyckades, Se logg för detaljerad info.</translation>
    </message>
</context>
<context>
    <name>BorgCreateJob</name>
    <message>
        <location filename="../../borg/create.py" line="36"/>
        <source>Backup finished with warnings. See logs for details.</source>
        <translation>Säkerhetskopiering slutfördes med varningar. Se loggar för detaljerad info.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="38"/>
        <source>Backup finished.</source>
        <translation>Säkerhetskopiering slutförd.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="45"/>
        <source>Backup started.</source>
        <translation>Säkerhetskopiering startad.</translation>
    </message>
</context>
<context>
    <name>BorgDeleteJob</name>
    <message>
        <location filename="../../borg/delete.py" line="8"/>
        <source>Deleting archive...</source>
        <translation>Tar bort arkiv...</translation>
    </message>
    <message>
        <location filename="../../borg/delete.py" line="13"/>
        <source>Archive deleted.</source>
        <translation>Arkiv borttaget.</translation>
    </message>
</context>
<context>
    <name>BorgDiffJob</name>
    <message>
        <location filename="../../borg/diff.py" line="9"/>
        <source>Requesting differences between archives...</source>
        <translation>Begär olikheter mellan arkiv...</translation>
    </message>
    <message>
        <location filename="../../borg/diff.py" line="13"/>
        <source>Obtained differences between archives.</source>
        <translation>Mottog olikheter mellan arkiv.</translation>
    </message>
</context>
<context>
    <name>BorgExtractJob</name>
    <message>
        <location filename="../../borg/extract.py" line="8"/>
        <source>Downloading files from archive...</source>
        <translation>Laddar ner filer från arkiv...</translation>
    </message>
    <message>
        <location filename="../../borg/extract.py" line="13"/>
        <source>Restored files from archive.</source>
        <translation>Återställde filer från arkiv.</translation>
    </message>
</context>
<context>
    <name>BorgInfoArchiveJob</name>
    <message>
        <location filename="../../borg/info_archive.py" line="9"/>
        <source>Refreshing archive...</source>
        <translation>Uppdaterar arkiv...</translation>
    </message>
    <message>
        <location filename="../../borg/info_archive.py" line="14"/>
        <source>Refreshing archive done.</source>
        <translation>Arkiv uppdaterade.</translation>
    </message>
</context>
<context>
    <name>BorgInfoRepoJob</name>
    <message>
        <location filename="../../borg/info_repo.py" line="9"/>
        <source>Validating existing repo...</source>
        <translation>Validerar befintligt förråd...</translation>
    </message>
</context>
<context>
    <name>BorgInitJob</name>
    <message>
        <location filename="../../borg/init.py" line="8"/>
        <source>Setting up new repo...</source>
        <translation>Skapar nytt förråd...</translation>
    </message>
</context>
<context>
    <name>BorgJob</name>
    <message>
        <location filename="../../borg/borg_job.py" line="66"/>
        <source>Files</source>
        <translation>Filer</translation>
    </message>
    <message>
        <location filename="../../borg/borg_job.py" line="67"/>
        <source>Original</source>
        <translation>Original</translation>
    </message>
    <message>
        <location filename="../../borg/borg_job.py" line="68"/>
        <source>Deduplicated</source>
        <translation>Deduplicerat</translation>
    </message>
    <message>
        <location filename="../../borg/borg_job.py" line="69"/>
        <source>Compressed</source>
        <translation>Komprimerat</translation>
    </message>
    <message>
        <location filename="../../borg/borg_job.py" line="299"/>
        <source>Task started</source>
        <translation>Åtgärd startad</translation>
    </message>
</context>
<context>
    <name>BorgListArchiveJob</name>
    <message>
        <location filename="../../borg/list_archive.py" line="8"/>
        <source>Getting archive content...</source>
        <translation>Hämtar arkivinnehåll...</translation>
    </message>
    <message>
        <location filename="../../borg/list_archive.py" line="12"/>
        <source>Done getting archive content.</source>
        <translation>Arkivinnehåll hämtat.</translation>
    </message>
</context>
<context>
    <name>BorgListRepoJob</name>
    <message>
        <location filename="../../borg/list_repo.py" line="10"/>
        <source>Refreshing archives...</source>
        <translation>Uppdaterar arkiv...</translation>
    </message>
    <message>
        <location filename="../../borg/list_repo.py" line="15"/>
        <source>Refreshing archives done.</source>
        <translation>Arkiv uppdaterade.</translation>
    </message>
</context>
<context>
    <name>BorgMountJob</name>
    <message>
        <location filename="../../borg/mount.py" line="9"/>
        <source>Mounting archive into folder...</source>
        <translation>Monterar arkiv i mapp...</translation>
    </message>
</context>
<context>
    <name>BorgPruneJob</name>
    <message>
        <location filename="../../borg/prune.py" line="9"/>
        <source>Pruning old archives...</source>
        <translation>Beskär gamla arkiv...</translation>
    </message>
    <message>
        <location filename="../../borg/prune.py" line="14"/>
        <source>Pruning done.</source>
        <translation>Beskärning slutförd.</translation>
    </message>
</context>
<context>
    <name>BorgUmountJob</name>
    <message>
        <location filename="../../borg/umount.py" line="10"/>
        <source>Unmounting archive...</source>
        <translation>Avmonterar arkiv...</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <location filename="../../assets/UI/extractdialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Dialog</translation>
    </message>
    <message>
        <location filename="../../assets/UI/extractdialog.ui" line="25"/>
        <source>Archive:</source>
        <translation>Arkiv:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/extractdialog.ui" line="38"/>
        <source>nyx2.local-2018-11-16T09:49:58 from November 16, 2018</source>
        <translation>nyx2.local-2018-11-16T09:49:58 från November 16, 2018</translation>
    </message>
    <message>
        <location filename="../../assets/UI/extractdialog.ui" line="63"/>
        <source>Note: If you select a top-level folder and deselect its children, they will still be restored.</source>
        <translation>Notera: Om du väljer en toppnivåmapp och väljer bort dess undermappar, kommer de ändå att återställas.</translation>
    </message>
    <message>
        <location filename="../../assets/UI/extractdialog.ui" line="88"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="../../assets/UI/extractdialog.ui" line="95"/>
        <source>Extract</source>
        <translation>Extrahera</translation>
    </message>
    <message>
        <location filename="../../assets/UI/profileadd.ui" line="35"/>
        <source>Add Backup Profile</source>
        <translation>Lägg till säkerhetskopieringsprofil</translation>
    </message>
    <message>
        <location filename="../../assets/UI/profileadd.ui" line="56"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Backup profiles allow for granular backups from different sources to different destinations. You could e.g. back up essential documents to a remote repository via Wifi, while doing a full backup onto a local storage device.&lt;/p&gt;&lt;p&gt;Repositories and SSH keys are shared between profiles. Source folders, active destination repo, allowed networks, pruning, validation and scheduling are per-profile.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Säkerhetskopieringsprofiler möjliggör detaljerade säkerhetskopior från olika källor till olika mål. Du kan t.ex. säkerhetskopiera viktiga dokument till ett fjärrförråd via Wifi, samtidigt som du gör en fullständig säkerhetskopia på en lokal lagringsenhet.&lt;/p&gt;&lt;p&gt;Förråd och SSH-nycklar delas mellan profiler. Källmappar, aktiva målförråd, tillåtna nätverk, beskärning, validering och schemaläggning är per profil.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/profileadd.ui" line="84"/>
        <source>Profile Name</source>
        <translation>Profilnamn</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="43"/>
        <source>Generate SSH Key</source>
        <translation>Generera SSH-nyckel</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="55"/>
        <source>Key Format:</source>
        <translation>Nyckelformat:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="72"/>
        <source>Key Length:</source>
        <translation>Nyckellängd:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="94"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;2048 or 4096 for RSA, 384 or 521 for ECDSA. Fixed for Ed25519. &lt;a href=&quot;https://stribika.github.io/2015/01/04/secure-secure-shell.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;More&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;2048 eller 4096 för RSA, 384 eller 521 för ECDSA. Fixad för Ed25519. &lt;a href=&quot;https://stribika.github.io/2015/01/04/secure-secure-shell.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0000ff;&quot;&gt;Mer&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="107"/>
        <source>Output File:</source>
        <translation>Utdatafil:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="119"/>
        <source>Don&apos;t change this if you want SSH to automatically find the key.</source>
        <translation>Ändra inte om du vill att SSH skall hitta nyckeln automatiskt.</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="128"/>
        <source>Close</source>
        <translation>Stäng</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sshadd.ui" line="141"/>
        <source>Generate and copy to Clipboard</source>
        <translation>Generera och kopiera till urklipp</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffdialog.ui" line="25"/>
        <source>Select two archives</source>
        <translation>Välj två arkiv</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffdialog.ui" line="60"/>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffdialog.ui" line="65"/>
        <source>Size</source>
        <translation>Storlek</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffdialog.ui" line="70"/>
        <source>Duration</source>
        <translation>Varaktighet</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffdialog.ui" line="75"/>
        <source>Mount Point</source>
        <translation>Moneringspunkt</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffdialog.ui" line="80"/>
        <source>Name</source>
        <translation>Namn</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffdialog.ui" line="113"/>
        <source>Diff</source>
        <translation>Diff</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffresult.ui" line="25"/>
        <source>Difference between</source>
        <translation>Skillnad mellan</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffresult.ui" line="38"/>
        <source>nyx2.local-2018-11-16T09:49:58 </source>
        <translation>nyx2.local-2018-11-16T09:49:58 </translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffresult.ui" line="45"/>
        <source>and</source>
        <translation>och</translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffresult.ui" line="58"/>
        <source>nyx2.local-2018-10-16T09:49:58 </source>
        <translation>nyx2.local-2018-10-16T09:49:58 </translation>
    </message>
    <message>
        <location filename="../../assets/UI/diffresult.ui" line="101"/>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../../assets/UI/exportwindow.ui" line="23"/>
        <source>If set, sharing this file with others will disclose your borg passphrase. Use with caution!</source>
        <translation>Vid aktivering, avslöjas din borg-lösenfras om du delar den här filen med andra. Använd detta med försiktighet!</translation>
    </message>
    <message>
        <location filename="../../assets/UI/exportwindow.ui" line="26"/>
        <source>Include borg passphrase in export</source>
        <translation>Ta med borg-lösenfrasen i exporten</translation>
    </message>
    <message>
        <location filename="../../assets/UI/importwindow.ui" line="25"/>
        <source>Borg passphrase:</source>
        <translation>Borg-lösenfras:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/importwindow.ui" line="53"/>
        <source>Overwrite existing profile</source>
        <translation>Skriv över befintlig profil</translation>
    </message>
    <message>
        <location filename="../../assets/UI/importwindow.ui" line="60"/>
        <source>Overwrite existing settings</source>
        <translation>Skriv över befintliga inställningar</translation>
    </message>
</context>
<context>
    <name>EditProfileWindow</name>
    <message>
        <location filename="../../views/profile_add_edit_dialog.py" line="68"/>
        <source>Rename Profile</source>
        <translation>Byt profilnamn</translation>
    </message>
</context>
<context>
    <name>ExistingRepoWindow</name>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="192"/>
        <source>Connect to existing Repository</source>
        <translation>Anslut till befintligt förråd</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="210"/>
        <source>Show my password</source>
        <translation>Visa mitt lösenord</translation>
    </message>
    <message>
        <location filename="../../views/repo_add_dialog.py" line="207"/>
        <source>Hide my password</source>
        <translation>Dölj mitt lösenord</translation>
    </message>
</context>
<context>
    <name>ExportWindow</name>
    <message>
        <location filename="../../views/export_window.py" line="29"/>
        <source>Export Profile</source>
        <translation>Exportera profil</translation>
    </message>
    <message>
        <location filename="../../views/export_window.py" line="38"/>
        <source>The current profile_export has no password</source>
        <translation>Den aktuella profile_export har inget lösenord</translation>
    </message>
    <message>
        <location filename="../../views/export_window.py" line="43"/>
        <source>Save profile_export</source>
        <translation>Spara profile_export</translation>
    </message>
    <message>
        <location filename="../../views/export_window.py" line="55"/>
        <source>Error while exporting</source>
        <translation>Fel vid export</translation>
    </message>
    <message>
        <location filename="../../views/export_window.py" line="71"/>
        <source>The file {} could not be created. Please choose another location.</source>
        <translation>Filen {} kunde inte skapas. Välj en annan plats.</translation>
    </message>
    <message>
        <location filename="../../views/export_window.py" line="78"/>
        <source>Profile export successful!</source>
        <translation>Profilexport slutförd!</translation>
    </message>
    <message>
        <location filename="../../views/export_window.py" line="78"/>
        <source>Profile export written to {}.</source>
        <translation>Profilexport skriven på {}.</translation>
    </message>
</context>
<context>
    <name>Form</name>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="14"/>
        <source>Form</source>
        <translation>Format</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="44"/>
        <source>Archives</source>
        <translation>Arkiv</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="72"/>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="79"/>
        <source>Size</source>
        <translation>Storlek</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="82"/>
        <source>Duration</source>
        <translation>Varaktighet</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="87"/>
        <source>Mount Point</source>
        <translation>Monteringspunkt</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="92"/>
        <source>Name</source>
        <translation>Namn</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="125"/>
        <source>Check</source>
        <translation>Kontrollera</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="145"/>
        <source>Prune</source>
        <translation>Beskär</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="155"/>
        <source>Refresh</source>
        <translation>Uppdatera</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="202"/>
        <source>Prune Options and Archive Naming</source>
        <translation>Beskärningsalternativ och arkivnamngivning</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="229"/>
        <source>Keep</source>
        <translation>Bevara</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="256"/>
        <source>Use -1 for unlimited.</source>
        <translation>Använd -1 för obegränsat.</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="249"/>
        <source> hourly, </source>
        <translation> varje timma, </translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="269"/>
        <source> daily, </source>
        <translation> varje dag, </translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="283"/>
        <source> weekly, </source>
        <translation> varje vecka, </translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="297"/>
        <source> monthly and</source>
        <translation> varje månad och</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="311"/>
        <source> annual archives</source>
        <translation> årliga arkiv</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="338"/>
        <source>No matter what, keep all archives of the last:</source>
        <translation>Oavsett, bevara alla arkiv för de senaste:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="348"/>
        <source>24H, 1d, 52w, 12m, 1y</source>
        <translation>24T, 1d, 52v, 12m, 1å</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="388"/>
        <source>Archive Name:</source>
        <translation>Arkivnamn:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="431"/>
        <source>Available variables: hostname, profile_id, profile_slug, now, utc_now, user</source>
        <translation>Tillgängliga variabler: hostname, profile_id, profile_slug, now, utc_now, user</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="398"/>
        <source>{hostname}-{profile_slug}-</source>
        <translation>{hostname}-{profile_slug}-</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="441"/>
        <source>Prune Prefix:</source>
        <translation>Beskärningsprefix:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/misctab.ui" line="71"/>
        <source>0.0</source>
        <translation>0.0</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="55"/>
        <source>Repository:</source>
        <translation>Förråd:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="128"/>
        <source>Select Backup Destination</source>
        <translation>Välj målmapp för säkerhetskopiering</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="136"/>
        <source>Unlink Repository (This doesn&apos;t delete any data. You can always add a repo again later.)</source>
        <translation>Avlänka förrådet (Detta tar inte bort någon data. Du kan alltid lägga till ett förråd igen, senare.)</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="164"/>
        <source>SSH Key:</source>
        <translation>SSH-nyckel:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="185"/>
        <source>Copy public SSH key to clipboard.</source>
        <translation>Kopiera offentlig SSH-nyckel till urklipp.</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="222"/>
        <source>To securely access remote repositories. Keep default to use all your existing keys. Or create new key.</source>
        <translation>Behåll standard för att använda alla befintliga nycklar, eller skapa en ny nyckel, för säker åtkomst till fjärrförråd.</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="246"/>
        <source>Compression:</source>
        <translation>Komprimering:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="347"/>
        <source>Encryption:</source>
        <translation>Kryptering:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="387"/>
        <source>Original Size:</source>
        <translation>Ursprunglig storlek:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="401"/>
        <source>Deduplicated Size:</source>
        <translation>Deduplicerad storlek:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="408"/>
        <source>Compressed Size:</source>
        <translation>Komprimerad storlek:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="45"/>
        <source>Schedule</source>
        <translation>Schema</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="86"/>
        <source>Backup manually</source>
        <translation>Säkerhetskopiera manuellt</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="143"/>
        <source>Backup every </source>
        <translation>Säkerhetskopiera varje </translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="110"/>
        <source>Backup daily at</source>
        <translation>Säkerhetskopiera varje dag</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="279"/>
        <source>Validate repository data every</source>
        <translation>Validera förrådsdata varje</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="299"/>
        <source>weeks</source>
        <translation>veckor</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="225"/>
        <source>Prune old Archives after each backup</source>
        <translation>Beskär gamla arkiv efter varje säkerhetskopiering</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="191"/>
        <source>Next Backup:</source>
        <translation>Nästa säkerhetskopiering:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="345"/>
        <source>Networks</source>
        <translation>Nätverk</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="357"/>
        <source>Allowed Networks:</source>
        <translation>Betrodda nätverk:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="406"/>
        <source>Log</source>
        <translation>Logg</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="431"/>
        <source>Time</source>
        <translation>Tid</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="436"/>
        <source>Category</source>
        <translation>Kategori</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="441"/>
        <source>Subcommand</source>
        <translation>Underkommando</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="446"/>
        <source>Repository</source>
        <translation>Förråd</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="451"/>
        <source>Returncode</source>
        <translation>Returkod</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="468"/>
        <source>Shell Commands</source>
        <translation>Skalkommandon</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="477"/>
        <source>Run custom shell commands before and after each backup. The actual backup and post-backup command will only run, if the pre-backup command exits without error (return code 0).</source>
        <translation>Kör anpassade skalkommandon före och efter säkerhetskopiering. Det faktiska säkerhetskopierings- och eftersäkerhetskopieringskommandot körs bara om kommandot före säkerhetskopieringen avslutas utan fel (returkod 0).</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="496"/>
        <source>Pre-backup command to run BEFORE backups</source>
        <translation>Försäkerhetskopieringskommando att köra FÖRE säkerhetskopiering</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="506"/>
        <source>Post-backup command to run AFTER backups</source>
        <translation>Eftersäkerhetskopieringskommando att köra EFTER säkerhetskopiering</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="519"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Available env variables: &lt;span style=&quot; font-family:&apos;Courier&apos;;&quot;&gt;$repo_url, $profile_name, $profile_slug, $returncode&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Tillgängliga miljövariabler: &lt;span style=&quot; font-family:&apos;Courier&apos;;&quot;&gt;$repo_url, $profile_name, $profile_slug, $returncode&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="20"/>
        <source>Source Folders and Files to Back Up:</source>
        <translation>Källmappar och filer att säkerhetskopiera:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="94"/>
        <source>Add Folder</source>
        <translation>Lägg till mapp</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="108"/>
        <source>Remove</source>
        <translation>Ta bort</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="164"/>
        <source>Exclude If Present (exclude folders with these files):</source>
        <translation>Undanta om finnes (undanta mappar med dessa filer):</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="135"/>
        <source>Diff</source>
        <translation>Diff</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="183"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;To mount archives, first install &amp;quot;FUSE for macOS&amp;quot; from &lt;a href=&quot;https://osxfuse.github.io/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;here&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;För att montera arkiv, installerarar du först &amp;quot;FUSE för macOS&amp;quot; from &lt;a href=&quot;https://osxfuse.github.io/&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;här&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="208"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Pruning removes older archives. You can choose the number of hourly, daily, etc. archives to preserve. Usually you will keep more newer and fewer old archives. Read &lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/prune.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#FF4500;&quot;&gt;more&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Beskärning tar bort äldre arkiv. Du kan välja antal arkiv att bevara per timma, dag etc. Normalt vill man bevara fler nyare och färre äldre arkiv. Läs &lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/prune.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#FF4500;&quot;&gt;mer&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/misctab.ui" line="64"/>
        <source>Vorta Version:</source>
        <translation>Vorta-version:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/misctab.ui" line="81"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;| &lt;a href=&quot;https://github.com/borgbase/vorta/issues/new/choose&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;Report&lt;/span&gt;&lt;/a&gt; a Bug |&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;| &lt;a href=&quot;https://github.com/borgbase/vorta/issues/new/choose&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;Rapportera&lt;/span&gt;&lt;/a&gt; ett fel |&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/misctab.ui" line="91"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;file:///&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;Log&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;a href=&quot;file:///&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;Logg&lt;/span&gt;&lt;/a&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/misctab.ui" line="127"/>
        <source>Borg Version:</source>
        <translation>Borg-version:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/misctab.ui" line="134"/>
        <source>1.1.8</source>
        <translation>1.1.8</translation>
    </message>
    <message>
        <location filename="../../assets/UI/misctab.ui" line="141"/>
        <source>/usr/bin/borg</source>
        <translation>/usr/bin/borg</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="96"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Remote or local backup repository. For simple and secure backup hosting, try &lt;a href=&quot;https://www.borgbase.com/?utm_source=vorta&amp;amp;utm_medium=app&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;BorgBase&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Fjärr- eller lokalt säkerhetskopieringsförråd. För enkel och säker lagring kan du prova &lt;a href=&quot;https://www.borgbase.com/?utm_source=vorta&amp;amp;utm_medium=app&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;BorgBase&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="288"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Compression used for new data. Can be changed and doesn&apos;t affect deduplication. Read &lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/help.html#borg-help-compression&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;more&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Komprimering använd för ny data. Kan ändras och påverkar inte deduplicering. Läs &lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/help.html#borg-help-compression&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;mer&lt;/span&gt;&lt;/a&gt;.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="154"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Exclude Patterns (&lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/help.html#borg-help-patterns&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;more&lt;/span&gt;&lt;/a&gt;):&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Undantagsmall. Läs (&lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/help.html#borg-help-patterns&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;mer&lt;/span&gt;&lt;/a&gt;):&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="180"/>
        <source>E.g. **/.cache</source>
        <translation>T.ex. **/.cache</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="193"/>
        <source>E.g. .nobackup</source>
        <translation>T.ex. .nobackup</translation>
    </message>
    <message>
        <location filename="../../assets/UI/repotab.ui" line="146"/>
        <source>Copy repo URL to clipboard</source>
        <translation>Kopiera förråds-URL till urklipp</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="364"/>
        <source>Don&apos;t run backup over metered networks</source>
        <translation>Kör inte säkerhetskopiering över nätverk med datamätare</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="101"/>
        <source>Add File(s)</source>
        <translation>Lägg till fil(er)</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="115"/>
        <source>One folder or file per line</source>
        <translation>En mapp eller fil per rad</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="118"/>
        <source>Paste Folders/Files</source>
        <translation>Klistra in mappar/filer</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="434"/>
        <source>{hostname}-{profile_slug}-{now:%Y-%m-%d-%H%M%S}</source>
        <translation>{hostname}-{profile_slug}-{now:%Y-%m-%d-%H%M%S}</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="69"/>
        <source>Path</source>
        <translation>Sökväg</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="74"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="84"/>
        <source>File Count</source>
        <translation>Antal filer</translation>
    </message>
    <message>
        <location filename="../../assets/UI/sourcetab.ui" line="125"/>
        <source>Recalculate sizes</source>
        <translation>Beräkna om storlekar</translation>
    </message>
    <message>
        <location filename="../../assets/UI/archivetab.ui" line="102"/>
        <source>Selected Archive</source>
        <translation>Valt arkiv</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="542"/>
        <source>Add these arguments when creating a backup. See &lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/create.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;the documentation&lt;/span&gt;&lt;/a&gt; for more information.</source>
        <translation>Lägg till dessa argument när en säkerhetskopia skapas. Se &lt;a href=&quot;https://borgbackup.readthedocs.io/en/stable/usage/create.html&quot;&gt;&lt;span style=&quot; text-decoration: underline; color:#0984e3;&quot;&gt;dokumentationen&lt;/span&gt;&lt;/a&gt; för mer information.</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="558"/>
        <source>Arguments to add. E.g. --dry-run</source>
        <translation>Argument att lägga till. T.ex. --dry-run</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="198"/>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <location filename="../../assets/UI/scheduletab.ui" line="252"/>
        <source>Run missed backups right after startup or wakeup</source>
        <translation>Kör saknade säkerhetskopieringar direkt efter uppstart eller väckning</translation>
    </message>
</context>
<context>
    <name>ImportWindow</name>
    <message>
        <location filename="../../views/import_window.py" line="25"/>
        <source>Import Profile</source>
        <translation>Importera profil</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="33"/>
        <source>The passphrase has been loaded from the export file</source>
        <translation>Lösenfrasen har lästs in från exportfilen</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="40"/>
        <source>The passphrase has been loaded from your keyring</source>
        <translation>Lösenfrasen har lästs in från din nyckelring</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="50"/>
        <source>A profile with the name {} does not exist. Nothing to overwrite.</source>
        <translation>Det finns ingen profil med namnet {}. Det finns inget att skriva över.</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="61"/>
        <source>Error while importing</source>
        <translation>Fel vid import</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="77"/>
        <source>Schema upgrade failure, file a bug report with the link in the Misc tab with the following error: 
 {0} 
 {1}</source>
        <translation>Schemauppgraderingsfel, skicka en felrapport med hjälp av länken i diversefliken och ange följande fel:
 {0}
 {1}</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="80"/>
        <source>Newer profile_export export files cannot be used on older versions.</source>
        <translation>Nyare profile_export exportfiler kan inte användas i äldre versioner.</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="82"/>
        <source>Cannot read profile_export export file due to permission error.</source>
        <translation>Kan inte läsa profile_export exportfil på grund av behörighetsfel.</translation>
    </message>
    <message>
        <location filename="../../views/import_window.py" line="84"/>
        <source>Profile export file not found.</source>
        <translation>Profilexportfil hittades inte</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../views/main_window.py" line="255"/>
        <source>Task cancelled</source>
        <translation>Aktivitet avbruten</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="20"/>
        <source>MainWindow</source>
        <translation>Huvudfönster</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="51"/>
        <source>Current Profile:</source>
        <translation>Aktuell profil:</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="84"/>
        <source>Rename Profile</source>
        <translation>Byt namn på profilen</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="107"/>
        <source>Delete Profile</source>
        <translation>Ta bort profilen</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="148"/>
        <source>Repository</source>
        <translation>Förråd</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="153"/>
        <source>Sources</source>
        <translation>Källor</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="158"/>
        <source>Schedule</source>
        <translation>Schema</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="163"/>
        <source>Archives</source>
        <translation>Arkiv</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="168"/>
        <source>Misc</source>
        <translation>Diverse</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="190"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="36"/>
        <source>Start Backup</source>
        <translation>Starta säkerhetskopiering</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="239"/>
        <source>Latest</source>
        <translation>Senast</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="244"/>
        <source>Reset App</source>
        <translation>Återställ programmet</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="68"/>
        <source>Add Profile</source>
        <translation>Lägg till profil</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="163"/>
        <source>Are you sure you want to delete profile &apos;{}&apos;?</source>
        <translation>Vill du verkligen ta bort profilen &quot;{}&quot;?</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="164"/>
        <source>Confirm deletion</source>
        <translation>Bekräfta borttagning</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="272"/>
        <source>Should Vorta continue to run in the background?</source>
        <translation>Skall Vorta fortsätta köra i bakgrunden?</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="277"/>
        <source>Quit</source>
        <translation>Avsluta</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="278"/>
        <source>Don&apos;t show this again</source>
        <translation>Visa inte detta igen</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="83"/>
        <source>Import from file...</source>
        <translation>Importera från fil...</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="174"/>
        <source>Can&apos;t delete the last profile.</source>
        <translation>Kan inte ta bort senaste profilen.</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="202"/>
        <source>Profile import successful!</source>
        <translation>Profilimport slutförd!</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="202"/>
        <source>Profile {} imported.</source>
        <translation>Profil {} importerad.</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="211"/>
        <source>Load profile</source>
        <translation>Läs in profil</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="211"/>
        <source>JSON (*.json);;All files (*)</source>
        <translation>JSON (*.json);;Alla filer (*)</translation>
    </message>
    <message>
        <location filename="../../assets/UI/mainwindow.ui" line="97"/>
        <source>Export Profile</source>
        <translation>Exportera profil</translation>
    </message>
    <message>
        <location filename="../../views/main_window.py" line="220"/>
        <source>Failed to import profile</source>
        <translation>Kunde inte importera profil</translation>
    </message>
</context>
<context>
    <name>RepoTab</name>
    <message>
        <location filename="../../views/repo_tab.py" line="26"/>
        <source>+ Initialize New Repository</source>
        <translation>+ Starta nytt förråd</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="27"/>
        <source>+ Add Existing Repository</source>
        <translation>+ Lägg till befintligt förråd</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="48"/>
        <source>No Compression</source>
        <translation>Ingen komprimering</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="111"/>
        <source>Automatically choose SSH Key (default)</source>
        <translation>Välj SSH-nyckel auomatiskt (standard)</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="112"/>
        <source>Create New Key</source>
        <translation>Skapa ny nyckel</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="149"/>
        <source>Public Key Copied to Clipboard</source>
        <translation>Offentlig nyckel kopierad till urklipp</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="150"/>
        <source>The selected public SSH key was copied to the clipboard. Use it to set up remote repo permissions.</source>
        <translation>Den valda offentliga SSH-nyckeln kopierades till urklipp. Använd den till att ställa in behörigheter för fjärrförråd.</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="155"/>
        <source>Couldn&apos;t find public key.</source>
        <translation>Kunde inte hitta offentlig nyckel.</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="157"/>
        <source>Select a public key from the dropdown first.</source>
        <translation>Välj först en offentlig nyckel i listrutan.</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="213"/>
        <source>Repository was Unlinked</source>
        <translation>Förrådet blev avlänkat</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="214"/>
        <source>You can always connect it again later.</source>
        <translation>Du kan alltid återansluta det senare.</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="38"/>
        <source>LZ4 (modern, default)</source>
        <translation>LZ4 (modern, standard)</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="39"/>
        <source>Zstandard Level 3 (modern)</source>
        <translation>Zstandard nivå 3 (modern)</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="40"/>
        <source>Zstandard Level 8 (modern)</source>
        <translation>Zstandard nivå 8 (modern)</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="46"/>
        <source>ZLIB Level 6 (auto, legacy)</source>
        <translation>ZLIB nivå 6 (auto, äldre)</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="47"/>
        <source>LZMA Level 6 (auto, legacy)</source>
        <translation>LZMA nivå 6 (auto, äldre)</translation>
    </message>
    <message>
        <location filename="../../views/repo_tab.py" line="228"/>
        <source>Select a repository from the dropdown first.</source>
        <translation>Välj först ett förråd från listrutan.</translation>
    </message>
</context>
<context>
    <name>SSHAddWindow</name>
    <message>
        <location filename="../../views/ssh_dialog.py" line="35"/>
        <source>ED25519 (Recommended)</source>
        <translation>ED25519 (Rekommenderas)</translation>
    </message>
    <message>
        <location filename="../../views/ssh_dialog.py" line="36"/>
        <source>RSA (Legacy)</source>
        <translation>RSA (Äldre)</translation>
    </message>
    <message>
        <location filename="../../views/ssh_dialog.py" line="37"/>
        <source>ECDSA</source>
        <translation>ECDSA</translation>
    </message>
    <message>
        <location filename="../../views/ssh_dialog.py" line="46"/>
        <source>High (Recommended)</source>
        <translation>Hög (Rekommenderas)</translation>
    </message>
    <message>
        <location filename="../../views/ssh_dialog.py" line="47"/>
        <source>Medium</source>
        <translation>Medel</translation>
    </message>
    <message>
        <location filename="../../views/ssh_dialog.py" line="60"/>
        <source>Key file already exists. Not overwriting.</source>
        <translation>Nyckelfilen finns redan. Skriver inte över.</translation>
    </message>
    <message>
        <location filename="../../views/ssh_dialog.py" line="72"/>
        <source>New key was copied to clipboard and written to %s.</source>
        <translation>Ny nyckel kopierades till urklipp och skrevs till %s.</translation>
    </message>
    <message>
        <location filename="../../views/ssh_dialog.py" line="74"/>
        <source>Error during key generation.</source>
        <translation>Fel vid nyckelgenerering.</translation>
    </message>
</context>
<context>
    <name>ScheduleTab</name>
    <message>
        <location filename="../../views/schedule_tab.py" line="43"/>
        <source>Minutes</source>
        <translation>Minuter</translation>
    </message>
    <message>
        <location filename="../../views/schedule_tab.py" line="44"/>
        <source>Hours</source>
        <translation>Timmar</translation>
    </message>
    <message>
        <location filename="../../views/schedule_tab.py" line="45"/>
        <source>Days</source>
        <translation>Dagar</translation>
    </message>
    <message>
        <location filename="../../views/schedule_tab.py" line="46"/>
        <source>Weeks</source>
        <translation>Veckor</translation>
    </message>
</context>
<context>
    <name>SourceTab</name>
    <message>
        <location filename="../../views/source_tab.py" line="173"/>
        <source>Choose directory to back up</source>
        <translation>Välj mapp att säkerhetskopiera</translation>
    </message>
    <message>
        <location filename="../../views/source_tab.py" line="173"/>
        <source>Choose file(s) to back up</source>
        <translation>Välj fil(er) att säkerhetskopiera</translation>
    </message>
    <message>
        <location filename="../../views/source_tab.py" line="130"/>
        <source>Folder</source>
        <translation>Mapp</translation>
    </message>
    <message>
        <location filename="../../views/source_tab.py" line="134"/>
        <source>File</source>
        <translation>Fil</translation>
    </message>
    <message>
        <location filename="../../views/source_tab.py" line="102"/>
        <source>Calculating...</source>
        <translation>Beräknar...</translation>
    </message>
    <message>
        <location filename="../../views/source_tab.py" line="164"/>
        <source>You don&apos;t have read access to {dir}.</source>
        <translation>Du har inte läsåtkomst till {dir}.</translation>
    </message>
</context>
<context>
    <name>TrayMenu</name>
    <message>
        <location filename="../../tray_menu.py" line="42"/>
        <source>Vorta for Borg Backup</source>
        <translation>Vorta för Borg Backup</translation>
    </message>
    <message>
        <location filename="../../tray_menu.py" line="53"/>
        <source>Cancel Backup</source>
        <translation>Avbryt säkerhetskopiering</translation>
    </message>
    <message>
        <location filename="../../tray_menu.py" line="56"/>
        <source>Next Task: %s</source>
        <translation>Nästa aktivitet: %s</translation>
    </message>
    <message>
        <location filename="../../tray_menu.py" line="65"/>
        <source>Backup Now</source>
        <translation>Säkerhetskopiera nu</translation>
    </message>
    <message>
        <location filename="../../tray_menu.py" line="70"/>
        <source>Quit</source>
        <translation>Avsluta</translation>
    </message>
    <message>
        <location filename="../../tray_menu.py" line="52"/>
        <source>Task in progress</source>
        <translation>Åtgärd pågår</translation>
    </message>
</context>
<context>
    <name>VortaApp</name>
    <message>
        <location filename="../../application.py" line="129"/>
        <source>Vorta Backup</source>
        <translation>Vorta säkerhetskopiering</translation>
    </message>
    <message>
        <location filename="../../application.py" line="191"/>
        <source>No Borg Binary Found</source>
        <translation>Ingen Borg-binär hittades</translation>
    </message>
    <message>
        <location filename="../../application.py" line="192"/>
        <source>Vorta was unable to locate a usable Borg Backup binary.</source>
        <translation>Vorta kunde inte hitta någon användbar Borg Backup-binär.</translation>
    </message>
    <message>
        <location filename="../../application.py" line="229"/>
        <source>Repository In Use</source>
        <translation>Förråd som används</translation>
    </message>
    <message>
        <location filename="../../application.py" line="231"/>
        <source>Abort</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="../../application.py" line="232"/>
        <source>Continue</source>
        <translation>Fortsätt</translation>
    </message>
    <message>
        <location filename="../../application.py" line="234"/>
        <source>The repository at {repo_url} might be in use elsewhere.</source>
        <translation>Förrådet på {repo_url} kanske används någon annan stans.</translation>
    </message>
    <message>
        <location filename="../../application.py" line="235"/>
        <source>Only break the lock if you are certain no other Borg process on any machine is accessing the repository. Abort or break the lock?</source>
        <translation>Bryt bara låset om du är säker på att ingen annan Borg-process, på någon maskin, använder förrådet. Vill du avbryta eller bryta låset?</translation>
    </message>
    <message>
        <location filename="../../application.py" line="243"/>
        <source>You do not have permission to access the repository at {repo_url}. Gain access and try again.</source>
        <translation>Du har inte behörighet att komma åt förrådet på {repo_url}. Skaffa åtkomst och försök igen.</translation>
    </message>
    <message>
        <location filename="../../application.py" line="246"/>
        <source>No Repository Permissions</source>
        <translation>Inga förrådsrättigheter</translation>
    </message>
    <message>
        <location filename="../../application.py" line="210"/>
        <source>Vorta needs Full Disk Access for complete Backups</source>
        <translation>Vorta behöver fullständig diskåtkomst för fullständiga säkerhetskopior</translation>
    </message>
    <message>
        <location filename="../../application.py" line="211"/>
        <source>Without this, some files won&apos;t be accessible and you may end up with an incomplete backup. Please set &lt;b&gt;Full Disk Access&lt;/b&gt; permission for Vorta in &lt;a href=&apos;x-apple.systempreferences:com.apple.preference.security?Privacy&apos;&gt;System Preferences &gt; Security &amp; Privacy&lt;/a&gt;.</source>
        <translation>Utan detta kommer vissa filer inte att vara tillgängliga och det kan sluta med en ofullständig säkerhetskopia.  Ange &lt;b&gt;fullständig diskåtkomstbehörighet&lt;/b&gt; för Vorta i &lt;a href=&apos;x-apple.systempreferences:com.apple.preference.security?Privacy&apos;&gt;Systeminställningar &gt; Säkerhet &amp; sekretess&lt;/a&gt;.</translation>
    </message>
    <message>
        <location filename="../../application.py" line="283"/>
        <source>Profile import successful!</source>
        <translation>Profilimport slutförd!</translation>
    </message>
    <message>
        <location filename="../../application.py" line="283"/>
        <source>Profile {} imported.</source>
        <translation>Profil {} importerad.</translation>
    </message>
    <message>
        <location filename="../../application.py" line="270"/>
        <source>Failed to import profile</source>
        <translation>Kunde inte importera profil</translation>
    </message>
    <message>
        <location filename="../../application.py" line="270"/>
        <source>Failed to import a profile from {}:</source>
        <translation>Kunde inte importera en profil från {}:</translation>
    </message>
    <message>
        <location filename="../../application.py" line="270"/>
        <source>Consider removing or repairing this file to get rid of this message.</source>
        <translation>Överväg att ta bort eller reparera denna fil, för att få bort detta meddelande.</translation>
    </message>
    <message>
        <location filename="../../application.py" line="295"/>
        <source>Repo Check Failed</source>
        <translation>Förrådskontroll misslyckades</translation>
    </message>
    <message>
        <location filename="../../application.py" line="296"/>
        <source>Repository data check for repo %s failed</source>
        <translation>Datakontroll för förrådet %s misslyckades</translation>
    </message>
    <message>
        <location filename="../../application.py" line="297"/>
        <source>Repair or recreate the repository soon to avoid missing data.</source>
        <translation>Reparera eller omskapa förrådet snart, för att undvika att data saknas.</translation>
    </message>
</context>
<context>
    <name>VortaScheduler</name>
    <message>
        <location filename="../../scheduler.py" line="143"/>
        <source>None scheduled</source>
        <translation>Ej schemalagd</translation>
    </message>
    <message>
        <location filename="../../scheduler.py" line="190"/>
        <source>Vorta Backup</source>
        <translation>Vorta säkerhetskopiering</translation>
    </message>
    <message>
        <location filename="../../scheduler.py" line="162"/>
        <source>Starting background backup for %s.</source>
        <translation>Starta säkerhetskopiering i bakgrunden för %s.</translation>
    </message>
    <message>
        <location filename="../../scheduler.py" line="184"/>
        <source>Backup successful for %s.</source>
        <translation>Säkerhetskopiering slutförd för %s.</translation>
    </message>
    <message>
        <location filename="../../scheduler.py" line="190"/>
        <source>Error during backup creation.</source>
        <translation>Fel vid skapande av säkerhetskopia.</translation>
    </message>
</context>
<context>
    <name>app</name>
    <message>
        <location filename="../../__main__.py" line="22"/>
        <source>Fatal Error</source>
        <translation>Allvarligt fel</translation>
    </message>
    <message>
        <location filename="../../__main__.py" line="23"/>
        <source>Uncaught exception, please file a report with this text at
https://github.com/borgbase/vorta/issues/new
</source>
        <translation>Oväntat undantag, skicka in en rapport med denna text inkluderad till
https://github.com/borgbase/vorta/issues/new
</translation>
    </message>
</context>
<context>
    <name>messages</name>
    <message>
        <location filename="../../borg/version.py" line="20"/>
        <source>Borg binary was not found.</source>
        <translation>Borg-binär hittades inte.</translation>
    </message>
    <message>
        <location filename="../../borg/borg_job.py" line="140"/>
        <source>Add a backup repository first.</source>
        <translation>Lägg först till ett säkerhetskopieringsförråd.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="82"/>
        <source>Add some folders to back up first.</source>
        <translation>Lägg först till någon mapp att säkerhetskopiera.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="98"/>
        <source>Current Wifi is not allowed.</source>
        <translation>Aktuellt Wifi är inte tillåtet.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="115"/>
        <source>Repo folder not mounted or moved.</source>
        <translation>Förrådsmapp inte monterad eller flyttad.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="111"/>
        <source>Pre-backup command returned non-zero exit code.</source>
        <translation>Kommandot före säkerhetskopiering returnerade en icke-nollavslutningskod.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="165"/>
        <source>Starting backup...</source>
        <translation>Startar säkerhetskopiering...</translation>
    </message>
    <message>
        <location filename="../../borg/umount.py" line="27"/>
        <source>No active Borg mounts found.</source>
        <translation>Inga aktiva Borg-monteringar hittades.</translation>
    </message>
    <message>
        <location filename="../../borg/borg_job.py" line="144"/>
        <source>Your Borg version is too old. &gt;=1.1.0 is required.</source>
        <translation>Din Borg-version är för gammal. &gt;=1.1.0 är obligatoriskt.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="119"/>
        <source>Your current Borg version does not support ZStd compression.</source>
        <translation>Din nuvarande Borg-version stödjer inte ZStd-komprimering.</translation>
    </message>
    <message>
        <location filename="../../borg/create.py" line="103"/>
        <source>Not running backup over metered connection.</source>
        <translation>Säkerhetskopiering över anslutning med datamätare körs inte.</translation>
    </message>
    <message>
        <location filename="../../borg/info_repo.py" line="43"/>
        <source>Please unlock your password manager.</source>
        <translation>Lås upp din lösenordshanterare.</translation>
    </message>
    <message>
        <location filename="../../borg/borg_job.py" line="171"/>
        <source>Your repo passphrase was stored in a password manager which is no longer available.
Try unlinking and re-adding your repo.</source>
        <translation>Din förrådslösenfras lagrades i en lösenordshanterare som inte längre är tillgänglig.
Försök avlänka och återansluta ditt förråd.</translation>
    </message>
    <message>
        <location filename="../../borg/borg_job.py" line="155"/>
        <source>Please unlock your system password manager or disable it under Misc</source>
        <translation>Lås upp din lösenordshanterare eller avaktivera den under Diverse</translation>
    </message>
</context>
<context>
    <name>utils</name>
    <message>
        <location filename="../../utils.py" line="412"/>
        <source>Passwords must be identical and greater than 8 characters long.</source>
        <translation>Lösenord måste vara identiska och längre än 8 tecken.</translation>
    </message>
    <message>
        <location filename="../../utils.py" line="414"/>
        <source>Passwords must be identical.</source>
        <translation>Lösenorden måste vara identiska.</translation>
    </message>
    <message>
        <location filename="../../utils.py" line="416"/>
        <source>Passwords must be greater than 8 characters long.</source>
        <translation>Lösenord måste vara längre än 8 tecken.</translation>
    </message>
</context>
</TS>